Quick differential expression visualization
visualize_dataset(
dataset,
genes = NULL,
adj_p_filter = 1,
rank_filter = Inf,
...
)Name or id of a dataset or a SummarizedExperiment as returned by get_dataset_object
An optional list of gene symbols or identifiers
P value threshold to filter genes
Positive integer or a ratio.
passed to get_dataset_object if dataset is a name
A list of pheatmap plots for every differential expression contrast of an experiment. Each plot will be subsetted to exclusively include the relevant subset for the contrast.